@@ -236,8 +236,6 @@ enaml wish list
 import ast
 import os
 import pathlib
-
-from abc import abstractmethod, ABC
 from copy import deepcopy
 from pprint import pformat
 from typing import Any, Callable, Dict, List, Optional, Tuple, Union
@@ -249,10 +247,10 @@ from ae.core import DEBUG_LEVEL_VERBOSE
 from ae.gui_app import id_of_flow, flow_action, flow_key, flow_path_strip, replace_flow_action  # type: ignore
 
 
-__version__ = '0.1.43'
+__version__ = '0.1.44'
 
 
-FLOW_PATH_ROOT_ID = 'ROOT'  #: pseudo item id needed for flow path jumper and for drop onto leave item button
+FLOW_PATH_ROOT_ID = '^^^^'  #: pseudo item id needed for flow path jumper and for drop onto leave item button
 FLOW_PATH_TEXT_SEP = " / "  #: flow path separator for :meth:`~LiszDataMixin.flow_path_text`
 
 FOCUS_FLOW_PREFIX = "->"    #: prefix shown in front of flow key of focused item
@@ -380,7 +378,7 @@ def item_unsel_filter(item: LiszItem) -> bool:
     return item.get('sel', 0) == 0
 
 
-class LiszDataMixin(ABC):
+class LiszDataMixin:
     """ lisz data model - independent from used GUI framework. """
     root_node: LiszNode             #: root of lisz data structure
     current_node_items: LiszNode    #: node item data of the current node / sub list (stored as app state via root_node)
@@ -396,36 +394,15 @@ class LiszDataMixin(ABC):
 
     _refreshing_data: bool = False                      #: DEBUG True while running :meth:`~.refresh_all` method
 
-    # abstract methods
-    # the gui_app methods are not really abstract (nor callable via super()) but declared here for proper type checking
-    @abstractmethod
-    def call_method(self, callback: Union[Callable, str], *args, **kwargs) -> Any:
-        """ call callable or method of this instance (ae.core.AppBase method). """
+    # abstract methods mostly implemented by :mod:`ae.gui_app`, some by the inheriting main app class
 
-    @abstractmethod
-    def call_method_delayed(self, delay: float, callback: Union[Callable, str], *args, **kwargs) -> Any:
-        """ delayed call callable or method of this instance (ae.gui_help.HelpAppBase). """
-
-    @abstractmethod
-    def change_app_state(self, app_state_name: str, state_value: Any, send_event: bool = True, old_name: str = ''):
-        """ add debug sound on each state change/save (ae.gui_app.MainAppBase method). """
-
-    @abstractmethod
-    def change_flow(self, new_flow_id: str, **event_kwargs) -> bool:
-        """ change/switch flow id. """
-
-    @abstractmethod
-    def flow_path_action(self, flow_path: Optional[List[str]] = None, path_index: int = -1) -> str:
-        """ determine the action of the last/newest entry in the flow_path (ae.gui_app.MainAppBase method). """
-
-    @abstractmethod
-    def play_sound(self, sound_name: str):
-        """ play audio/sound file (ae.gui_app.MainAppBase method). """
-
-    # this a real abstract method (to be implemented by inheriting class)
-    @abstractmethod
-    def refresh_node_widgets(self):
-        """ redraw/refresh the widgets representing the current node items/sub-nodes (GUI framework method). """
+    call_method: Callable
+    call_method_delayed: Callable
+    change_app_state: Callable
+    change_flow: Callable
+    flow_path_action: Callable
+    play_sound: Callable
+    refresh_node_widgets: Callable      # implemented by the inheriting main app class
 
     # helper methods
 
@@ -781,6 +758,11 @@ class LiszDataMixin(ABC):
                 idx = min(max(-1, delta), 0)
             self.change_flow(id_of_flow('focus', 'item', self.current_node_items[filtered_indexes[idx]]['id']))
 
+    def global_variables(self, **patches) -> Dict[str, Any]:
+        """ overridden to add app-specific globals. """
+        # noinspection PyUnresolvedReferences
+        return super().global_variables(FLOW_PATH_ROOT_ID=FLOW_PATH_ROOT_ID, **patches)  # type: ignore
+
     def importable_node_files(self, folder_path: str = ".") -> NodeFilesInfo:
         """ load and check all nodes found in the documents app folder of this app.
 
